# Raftel

Raftel is a library to easily plot s2id cell into map and other basic operation related to s2id mapping.
Basicaly a thinly veiled wrapper of the excellent [s2sphere](https://github.com/sidewalklabs/s2sphere), the native python implementation of the outstanding [s2-geometry](https://github.com/google/s2geometry) package from Google, and simple mapping function using staticmap library.

## Installation
Install directly from pyPI by running `pip install raftel`

## Example
Follow the example in the notebook for basic usage.
